@@ -1,6 +1,7 @@
 import os
 from typing import Collection, Dict, Iterable, List, Optional, Sequence, Set, Tuple
 
+from metaphor.common.git import clone_repo
 from metaphor.models.crawler_run_metadata import Platform
 
 try:
@@ -11,6 +12,12 @@ except ImportError:
     print("Please install metaphor[looker] extra\n")
     raise
 
+from metaphor.common.entity_id import to_virtual_view_entity_id
+from metaphor.common.event_util import ENTITY_TYPES
+from metaphor.common.extractor import BaseExtractor
+from metaphor.common.logger import get_logger
+from metaphor.looker.config import LookerConnectionConfig, LookerRunConfig
+from metaphor.looker.lookml_parser import Model, fullname, parse_project
 from metaphor.models.metadata_change_event import (
     Chart,
     ChartType,
@@ -23,13 +30,6 @@ from metaphor.models.metadata_change_event import (
     VirtualViewType,
 )
 
-from metaphor.common.entity_id import to_virtual_view_entity_id
-from metaphor.common.event_util import ENTITY_TYPES
-from metaphor.common.extractor import BaseExtractor
-from metaphor.common.logger import get_logger
-from metaphor.looker.config import LookerConnectionConfig, LookerRunConfig
-from metaphor.looker.lookml_parser import Model, fullname, parse_project
-
 logger = get_logger(__name__)
 
 
@@ -87,8 +87,11 @@ class LookerExtractor(BaseExtractor):
             k.lower(): v for (k, v) in config.connections.items()
         }
 
+        lookml_dir = config.lookml_dir or clone_repo(config.lookml_git_repo)
+        logger.info(f"Parsing LookML project at {lookml_dir}")
+
         model_map, virtual_views = parse_project(
-            config.lookml_dir, connections, config.project_source_url
+            lookml_dir, connections, config.project_source_url
         )
 
         dashboards = self._fetch_dashboards(config, sdk, model_map)
