@@ -1,7 +1,6 @@
 from datetime import datetime, timezone
 from typing import Collection, Dict, List, Mapping, Optional
 
-from metaphor.models.crawler_run_metadata import Platform
 from snowflake.connector import SnowflakeConnection
 from snowflake.connector.cursor import DictCursor, SnowflakeCursor
 
@@ -9,6 +8,7 @@ from metaphor.common.entity_id import dataset_fullname
 from metaphor.common.event_util import ENTITY_TYPES
 from metaphor.common.filter import DatasetFilter
 from metaphor.common.logger import get_logger
+from metaphor.models.crawler_run_metadata import Platform
 from metaphor.snowflake.auth import connect
 from metaphor.snowflake.config import SnowflakeRunConfig
 from metaphor.snowflake.utils import DatasetInfo, SnowflakeTableType
@@ -19,6 +19,7 @@ except ImportError:
     print("Please install metaphor[snowflake] extra\n")
     raise
 
+from metaphor.common.extractor import BaseExtractor
 from metaphor.models.metadata_change_event import (
     AspectType,
     DataPlatform,
@@ -34,8 +35,6 @@ from metaphor.models.metadata_change_event import (
     SQLSchema,
 )
 
-from metaphor.common.extractor import BaseExtractor
-
 logger = get_logger(__name__)
 
 
@@ -81,6 +80,10 @@ class SnowflakeExtractor(BaseExtractor):
 
             for database in databases:
                 tables = self._fetch_tables(cursor, database, filter)
+                if len(tables) == 0:
+                    logger.info(f"Skip empty database {database}")
+                    continue
+
                 logger.info(f"Include {len(tables)} tables from {database}")
 
                 self._fetch_columns(cursor, database)
@@ -163,7 +166,6 @@ class SnowflakeExtractor(BaseExtractor):
         ) in cursor:
             full_name = dataset_fullname(database, table_schema, table_name)
             if full_name not in self._datasets:
-                logger.warning(f"Table {full_name} not found")
                 continue
 
             dataset = self._datasets[full_name]
@@ -199,8 +201,16 @@ class SnowflakeExtractor(BaseExtractor):
             params.append(fullname)
             ddl_tables.append(fullname)
 
+        query = f"SELECT {','.join(queries)}"
+
         cursor = conn.cursor(DictCursor)
-        cursor.execute(f"SELECT {','.join(queries)}", tuple(params))
+
+        try:
+            cursor.execute(query, tuple(params))
+        except Exception as e:
+            logger.exception(f"Failed to execute query:\n{query}\n{e}")
+            return
+
         results = cursor.fetchone()
         assert isinstance(results, Mapping)
         cursor.close()
